# Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## [1.0.0] - 2016-06-06
### Changed
- Browser support is fixed
- Marked as stable

## [0.0.4] - 2015-11-23
### Changed
- Switched to [Keep a Changelog](http://keepachangelog.com/) spec for CHANGELOG.md
- Creates an `options.filename` for `*File()` functions, if one is not provided

## [0.0.3] - 2015-07-13
### Added
- Added `.render()` fallbacks for `.compile()`

### Changed
- Prefers locals over options when passing a single argument to `.render()`
- Updated dependencies

## [0.0.2] - 2015-04-11
### Added
- Now have a logo
- Added tests

### Changed
- Updated documentation

## 0.0.1 - 2015-02-09
### Added
- Initial release

[1.0.0]: https://github.com/jstransformers/jstransformer/compare/0.0.4...1.0.0
[0.0.4]: https://github.com/jstransformers/jstransformer/compare/0.0.3...0.0.4
[0.0.3]: https://github.com/jstransformers/jstransformer/compare/0.0.2...0.0.3
[0.0.2]: https://github.com/jstransformers/jstransformer/compare/0.0.1...0.0.2
